import os


class AuthenticationSetup:
    def __init__(self):
        self

    def enable_proxy(self, proxy_with_port):
        proxy = proxy_with_port
        os.environ['http_proxy'] = proxy
        os.environ['HTTP_PROXY'] = proxy
        os.environ['https_proxy'] = proxy
        os.environ['httpS_proxy'] = proxy




from setuptools import setup
from setuptools import find_namespace_packages

with open("README.md", "r", encoding="utf-8") as fh:
    long_description = fh.read()

setup(
    name="proxyauthenticator",
    version="0.0.3",
    author="Nuwan Chaminda",
    author_email="lokupodda123@gmail.com",
    description="Proxy Authenticator for python projects",
    long_description="file: README.md",
    long_description_content_type="text/markdown",
    url="https://github.com/NuwanChaminda/proxyauthenticator",

    # package_dir={"": "src"},
    # Specify folder content.
    packages=find_namespace_packages(
        include=['AuthenticatorOverride']
    ),
    python_requires=">=3.6",
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
        # Programming Languages Used..
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8'
    ]
)
